Learn R Programming

spBFA (version 1.5.0)

is.spBFA: is.spBFA

Description

is.spBFA is a general test of an object being interpretable as a spBFA object.

Usage

is.spBFA(x)

Value

is.spBFA returns a logical, depending on whether the object is of class spBFA.

Arguments

x

object to be tested.

Details

The spBFA class is defined as the regression object that results from the spBFA regression function.

Examples

Run this code
###Load pre-computed results
data(reg.bfa_sp)

###Test function
is.spBFA(reg.bfa_sp)

Run the code above in your browser using DataLab