powered by
is.spBFA is a general test of an object being interpretable as a spBFA object.
is.spBFA
spBFA
is.spBFA(x)
is.spBFA returns a logical, depending on whether the object is of class spBFA.
object to be tested.
The spBFA class is defined as the regression object that results from the spBFA regression function.
###Load pre-computed results data(reg.bfa_sp) ###Test function is.spBFA(reg.bfa_sp)
Run the code above in your browser using DataLab